==> gengetopt-2.12.2.tar.gz: gengetopt-2.12.2/src/gm_utils.cpp <==
//
// C++ Implementation: gm_utils
//
// Description:
//
//
// Author: Lorenzo Bettini <bettini@gnu.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//

#include "gm_utils.h"
#include "my_sstream.h"
#include "ggo_options.h"
#include "argsdef.h"

/*
  return a copy of the string passed after canonizing it (i.e. '-' and
  '.' are transformed in '_'.
*/
char *
canonize_names (const char *name)
{
  char *pvar;
  char *p;

  pvar = strdup (name);

  for (p = pvar; *p; ++p)
    if (*p == '.' || *p == '-') *p = '_';

  return pvar;
}

// remove the path from the file name
const string
strip_path(const string &s)
{
  string::size_type pos_of_sep;

  pos_of_sep = s.rfind("/");
  if (pos_of_sep == string::npos)
    pos_of_sep = s.rfind("\\"); // try also with DOS path sep

  if (pos_of_sep == string::npos)
    return s; // no path

  return s.substr (pos_of_sep + 1);
}

const string
to_upper(const string &old)
{
  string upper = old;

  for (string::iterator s = upper.begin ();
       s != upper.end (); ++s)
    *s = toupper (*s);

  return upper;
}

const string
canonize_name(const string &old)
{
  string canonized = old;

  for (string::iterator s = canonized.begin ();
       s != canonized.end (); ++s)
    if (*s == '.' || *s == '-' || *s == ' ') *s = '_';

  return canonized;
}

bool
has_multiple_options_string()
{
  if (! has_multiple_options ())
    return false;

  struct gengetopt_option * opt;

  foropt
  {
    if (opt->multiple && opt->type == ARG_STRING)
      return true;
  }

  return false;
}

bool
has_multiple_options()
{
  struct gengetopt_option * opt;

  foropt
  {
    if (opt->multiple)
      return true;
  }

  return false;
}

bool
has_options()
{
  struct gengetopt_option * opt;

  foropt
  {
    if (opt->short_opt)
      {
        if (opt->short_opt != 'h' && opt->short_opt != 'V')
          return true;
      }
  }

  return false;
}

inline static int
char_is_newline(const string &buf)
{
  string::size_type  notnewline = buf.find_first_not_of("\r\n");
  if (notnewline)
    return notnewline;

  if (buf.size() > 1 && buf[0] == '\\' && buf[1] == 'n')
    return 2;

  return 0;
}

void
wrap_cstr( string& wrapped, unsigned int from_column, unsigned int second_indent, const string &orig )
{
  int  next_space = from_column;
  string next_word;
  const char * out_buf = orig.c_str();
  ostringstream stream;
  const unsigned int second_line_column = from_column + second_indent;
  string indent (second_line_column, ' ');
  int newline_chars = 0;

  while (*out_buf)
    {
      // check for a new line
      if (*out_buf)
        if ((newline_chars = char_is_newline(out_buf)))
          {
            stream << "\\n";
            out_buf += newline_chars;

            if (*out_buf)
              {
                stream << indent;
                next_space = second_line_column;
                continue;
              }
            else
              break;
         }
       else
         {
           stream << *out_buf++;
           next_space++;
         }

      // search next whitespace, i.e., next word
      while ((*out_buf) && (*out_buf != ' ') &&
             ! char_is_newline(out_buf))
        {
          next_word += *out_buf++;
          next_space++;
        }

      // wrap line if it's too long
      if (next_space > 79)
        {
          stream << "\\n" << indent << next_word;
          next_space = second_line_column + next_word.size();
        }
      else
        stream << next_word; // simply write word

      next_word = "";
    }

  wrapped += stream.str();
}

==> gengetopt-2.13.tar.gz: gengetopt-2.13/src/gm_utils.cpp <==
//
// C++ Implementation: gm_utils
//
// Description:
//
//
// Author: Lorenzo Bettini <bettini@gnu.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//

#include "gm_utils.h"
#include "my_sstream.h"
#include "ggo_options.h"
#include "argsdef.h"

/*
  return a copy of the string passed after canonizing it (i.e. '-' and
  '.' are transformed in '_'.
*/
char *
canonize_names (const char *name)
{
  char *pvar;
  char *p;

  pvar = strdup (name);

  for (p = pvar; *p; ++p)
    if (*p == '.' || *p == '-') *p = '_';

  return pvar;
}

// remove the path from the file name
const string
strip_path(const string &s)
{
  string::size_type pos_of_sep;

  pos_of_sep = s.rfind("/");
  if (pos_of_sep == string::npos)
    pos_of_sep = s.rfind("\\"); // try also with DOS path sep

  if (pos_of_sep == string::npos)
    return s; // no path

  return s.substr (pos_of_sep + 1);
}

const string
to_upper(const string &old)
{
  string upper = old;

  for (string::iterator s = upper.begin ();
       s != upper.end (); ++s)
    *s = toupper (*s);

  return upper;
}

const string
canonize_name(const string &old)
{
  string canonized = old;

  for (string::iterator s = canonized.begin ();
       s != canonized.end (); ++s)
    if (*s == '.' || *s == '-' || *s == ' ') *s = '_';

  return canonized;
}

bool
has_multiple_options_string()
{
  if (! has_multiple_options ())
    return false;

  struct gengetopt_option * opt = 0;

  foropt
  {
    if (opt->multiple && opt->type == ARG_STRING)
      return true;
  }

  return false;
}

bool
has_multiple_options()
{
  struct gengetopt_option * opt = 0;

  foropt
  {
    if (opt->multiple)
      return true;
  }

  return false;
}

bool
has_multiple_options_with_type()
{
  struct gengetopt_option * opt = 0;

  foropt
  {
    if (opt->multiple && opt->type)
      return true;
  }

  return false;
}

bool
has_required()
{
  struct gengetopt_option * opt = 0;

  foropt
  {
    if (opt->required)
      return true;
  }

  return false;
}

bool
has_options()
{
  struct gengetopt_option * opt = 0;

  foropt
  {
    if (opt->short_opt)
      {
        if (opt->short_opt != 'h' && opt->short_opt != 'V')
          return true;
      }
  }

  return false;
}

bool
has_values()
{
  struct gengetopt_option * opt = 0;

  foropt
  {
    if (opt->acceptedvalues)
      {
        return true;
      }
  }

  return false;
}

inline static int
char_is_newline(const string &buf)
{
  string::size_type  notnewline = buf.find_first_not_of("\r\n");
  if (notnewline)
    return notnewline;

  if (buf.size() > 1 && buf[0] == '\\' && buf[1] == 'n')
    return 2;

  return 0;
}

void
wrap_cstr( string& wrapped, unsigned int from_column, unsigned int second_indent, const string &orig )
{
  int  next_space = from_column;
  string next_word;
  const char * out_buf = orig.c_str();
  ostringstream stream;
  const unsigned int second_line_column = from_column + second_indent;
  string indent (second_line_column, ' ');
  int newline_chars = 0;

  while (*out_buf)
    {
      // check for a new line
      if (*out_buf)
        if ((newline_chars = char_is_newline(out_buf)))
          {
            stream << "\\n";
            out_buf += newline_chars;

            if (*out_buf)
              {
                stream << indent;
                next_space = second_line_column;
                continue;
              }
            else
              break;
         }
       else
         {
           stream << *out_buf++;
           next_space++;
         }

      // search next whitespace, i.e., next word
      while ((*out_buf) && (*out_buf != ' ') &&
             ! char_is_newline(out_buf))
        {
          next_word += *out_buf++;
          next_space++;
        }

      // wrap line if it's too long
      if (next_space > 79)
        {
          stream << "\\n" << indent << next_word;
          next_space = second_line_column + next_word.size();
        }
      else
        stream << next_word; // simply write word

      next_word = "";
    }

  wrapped += stream.str();
}
